==> kubernetes-model-extensions-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/extensions/NetworkPolicyIngressRuleFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NetworkPolicyIngressRuleFluent<A extends NetworkPolicyIngressRuleFluent<A>> extends Fluent<A>{
  public A addToFrom(Integer index,NetworkPolicyPeer item);
  public A setToFrom(Integer index,NetworkPolicyPeer item);
  public A addToFrom(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPeer... items);
  public A addAllToFrom(Collection<NetworkPolicyPeer> items);
  public A removeFromFrom(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPeer... items);
  public A removeAllFromFrom(Collection<NetworkPolicyPeer> items);
  public A removeMatchingFromFrom(Predicate<NetworkPolicyPeerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFrom instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<NetworkPolicyPeer> getFrom();
  public List<NetworkPolicyPeer> buildFrom();
  public NetworkPolicyPeer buildFrom(Integer index);
  public NetworkPolicyPeer buildFirstFrom();
  public NetworkPolicyPeer buildLastFrom();
  public NetworkPolicyPeer buildMatchingFrom(Predicate<NetworkPolicyPeerBuilder> predicate);
  public Boolean hasMatchingFrom(Predicate<NetworkPolicyPeerBuilder> predicate);
  public A withFrom(List<NetworkPolicyPeer> from);
  public A withFrom(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPeer... from);
  public Boolean hasFrom();
  public NetworkPolicyIngressRuleFluent.FromNested<A> addNewFrom();
  public NetworkPolicyIngressRuleFluent.FromNested<A> addNewFromLike(NetworkPolicyPeer item);
  public NetworkPolicyIngressRuleFluent.FromNested<A> setNewFromLike(Integer index,NetworkPolicyPeer item);
  public NetworkPolicyIngressRuleFluent.FromNested<A> editFrom(Integer index);
  public NetworkPolicyIngressRuleFluent.FromNested<A> editFirstFrom();
  public NetworkPolicyIngressRuleFluent.FromNested<A> editLastFrom();
  public NetworkPolicyIngressRuleFluent.FromNested<A> editMatchingFrom(Predicate<NetworkPolicyPeerBuilder> predicate);
  public A addToPorts(Integer index,NetworkPolicyPort item);
  public A setToPorts(Integer index,NetworkPolicyPort item);
  public A addToPorts(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPort... items);
  public A addAllToPorts(Collection<NetworkPolicyPort> items);
  public A removeFromPorts(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPort... items);
  public A removeAllFromPorts(Collection<NetworkPolicyPort> items);
  public A removeMatchingFromPorts(Predicate<NetworkPolicyPortBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPorts instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<NetworkPolicyPort> getPorts();
  public List<NetworkPolicyPort> buildPorts();
  public NetworkPolicyPort buildPort(Integer index);
  public NetworkPolicyPort buildFirstPort();
  public NetworkPolicyPort buildLastPort();
  public NetworkPolicyPort buildMatchingPort(Predicate<NetworkPolicyPortBuilder> predicate);
  public Boolean hasMatchingPort(Predicate<NetworkPolicyPortBuilder> predicate);
  public A withPorts(List<NetworkPolicyPort> ports);
  public A withPorts(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPort... ports);
  public Boolean hasPorts();
  public NetworkPolicyIngressRuleFluent.PortsNested<A> addNewPort();
  public NetworkPolicyIngressRuleFluent.PortsNested<A> addNewPortLike(NetworkPolicyPort item);
  public NetworkPolicyIngressRuleFluent.PortsNested<A> setNewPortLike(Integer index,NetworkPolicyPort item);
  public NetworkPolicyIngressRuleFluent.PortsNested<A> editPort(Integer index);
  public NetworkPolicyIngressRuleFluent.PortsNested<A> editFirstPort();
  public NetworkPolicyIngressRuleFluent.PortsNested<A> editLastPort();
  public NetworkPolicyIngressRuleFluent.PortsNested<A> editMatchingPort(Predicate<NetworkPolicyPortBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface FromNested<N> extends Nested<N>,NetworkPolicyPeerFluent<NetworkPolicyIngressRuleFluent.FromNested<N>>{
    public N and();
    public N endFrom();
    
  }
  public interface PortsNested<N> extends Nested<N>,NetworkPolicyPortFluent<NetworkPolicyIngressRuleFluent.PortsNested<N>>{
    public N and();
    public N endPort();
    
  }
  
}

==> kubernetes-model-extensions-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/extensions/NetworkPolicyIngressRuleFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface NetworkPolicyIngressRuleFluent<A extends NetworkPolicyIngressRuleFluent<A>> extends Fluent<A>{
  public A addToFrom(int index,NetworkPolicyPeer item);
  public A setToFrom(int index,NetworkPolicyPeer item);
  public A addToFrom(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPeer... items);
  public A addAllToFrom(Collection<NetworkPolicyPeer> items);
  public A removeFromFrom(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPeer... items);
  public A removeAllFromFrom(Collection<NetworkPolicyPeer> items);
  public A removeMatchingFromFrom(Predicate<NetworkPolicyPeerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFrom instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<NetworkPolicyPeer> getFrom();
  public List<NetworkPolicyPeer> buildFrom();
  public NetworkPolicyPeer buildFrom(int index);
  public NetworkPolicyPeer buildFirstFrom();
  public NetworkPolicyPeer buildLastFrom();
  public NetworkPolicyPeer buildMatchingFrom(Predicate<NetworkPolicyPeerBuilder> predicate);
  public Boolean hasMatchingFrom(Predicate<NetworkPolicyPeerBuilder> predicate);
  public A withFrom(List<NetworkPolicyPeer> from);
  public A withFrom(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPeer... from);
  public Boolean hasFrom();
  public NetworkPolicyIngressRuleFluent.FromNested<A> addNewFrom();
  public NetworkPolicyIngressRuleFluent.FromNested<A> addNewFromLike(NetworkPolicyPeer item);
  public NetworkPolicyIngressRuleFluent.FromNested<A> setNewFromLike(int index,NetworkPolicyPeer item);
  public NetworkPolicyIngressRuleFluent.FromNested<A> editFrom(int index);
  public NetworkPolicyIngressRuleFluent.FromNested<A> editFirstFrom();
  public NetworkPolicyIngressRuleFluent.FromNested<A> editLastFrom();
  public NetworkPolicyIngressRuleFluent.FromNested<A> editMatchingFrom(Predicate<NetworkPolicyPeerBuilder> predicate);
  public A addToPorts(int index,NetworkPolicyPort item);
  public A setToPorts(int index,NetworkPolicyPort item);
  public A addToPorts(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPort... items);
  public A addAllToPorts(Collection<NetworkPolicyPort> items);
  public A removeFromPorts(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPort... items);
  public A removeAllFromPorts(Collection<NetworkPolicyPort> items);
  public A removeMatchingFromPorts(Predicate<NetworkPolicyPortBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPorts instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<NetworkPolicyPort> getPorts();
  public List<NetworkPolicyPort> buildPorts();
  public NetworkPolicyPort buildPort(int index);
  public NetworkPolicyPort buildFirstPort();
  public NetworkPolicyPort buildLastPort();
  public NetworkPolicyPort buildMatchingPort(Predicate<NetworkPolicyPortBuilder> predicate);
  public Boolean hasMatchingPort(Predicate<NetworkPolicyPortBuilder> predicate);
  public A withPorts(List<NetworkPolicyPort> ports);
  public A withPorts(io.fabric8.kubernetes.api.model.extensions.NetworkPolicyPort... ports);
  public Boolean hasPorts();
  public NetworkPolicyIngressRuleFluent.PortsNested<A> addNewPort();
  public NetworkPolicyIngressRuleFluent.PortsNested<A> addNewPortLike(NetworkPolicyPort item);
  public NetworkPolicyIngressRuleFluent.PortsNested<A> setNewPortLike(int index,NetworkPolicyPort item);
  public NetworkPolicyIngressRuleFluent.PortsNested<A> editPort(int index);
  public NetworkPolicyIngressRuleFluent.PortsNested<A> editFirstPort();
  public NetworkPolicyIngressRuleFluent.PortsNested<A> editLastPort();
  public NetworkPolicyIngressRuleFluent.PortsNested<A> editMatchingPort(Predicate<NetworkPolicyPortBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface FromNested<N> extends Nested<N>,NetworkPolicyPeerFluent<NetworkPolicyIngressRuleFluent.FromNested<N>>{
    public N and();
    public N endFrom();
    
  }
  public interface PortsNested<N> extends Nested<N>,NetworkPolicyPortFluent<NetworkPolicyIngressRuleFluent.PortsNested<N>>{
    public N and();
    public N endPort();
    
  }
  
}
